@@ -9,7 +9,7 @@ and at http://creativecommons.org/licenses/by-nc-sa/3.0/legalcode>
 */
 
 #include <iostream>
-using namespace std;
+//using namespace std;
 #include <algorithm>
 #include <ctime>
 #include <cmath>
@@ -23,7 +23,7 @@ using namespace std;
 extern "C" 
 {
 SEXP aracne(SEXP mim, SEXP nbvar, SEXP e);
-SEXP clr(SEXP mim, SEXP nbvar);
+SEXP clr(SEXP mim, SEXP nbvar,SEXP skipDiagonal);
 SEXP mrnet( SEXP mim, SEXP nbvar);
 SEXP mrnetb( SEXP mim, SEXP nbvar);
 SEXP validate( SEXP inet,SEXP tnet,SEXP n);
